@@ -20,12 +20,12 @@ CharacterRunnerConfigForm::CharacterRunnerConfigForm(QWidget *parent)
     setupUi(this);
 }
 
-CharacterRunnerConfig::CharacterRunnerConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
+CharacterRunnerConfig::CharacterRunnerConfig(QObject *parent, const KPluginMetaData &metaData)
+    : KCModule(parent, metaData)
 {
-    m_ui = new CharacterRunnerConfigForm(this);
+    m_ui = new CharacterRunnerConfigForm(widget());
 
-    QGridLayout *layout = new QGridLayout(this);
+    QGridLayout *layout = new QGridLayout(widget());
     layout->addWidget(m_ui, 0, 0);
 
     connect(m_ui->edit_trigger, &QLineEdit::textChanged, this, &CharacterRunnerConfig::markAsChanged);
@@ -43,7 +43,7 @@ void CharacterRunnerConfig::load()
     KCModule::load();
 
     KSharedConfig::Ptr cfg = KSharedConfig::openConfig(QStringLiteral("krunnerrc"));
-    KConfigGroup grp = cfg->group("Runners").group("CharacterRunner");
+    KConfigGroup grp = cfg->group("Runners").group(KRUNNER_PLUGIN_NAME);
 
     m_ui->edit_trigger->setText(grp.readEntry(CONFIG_TRIGGERWORD, DEFAULT_TRIGGERWORD.toString()));
     const auto aliasList = grp.readEntry(CONFIG_ALIASES, QStringList());
@@ -58,7 +58,7 @@ void CharacterRunnerConfig::load()
     } else {
         const auto msg = new KMessageWidget(i18nc("Message that config is corrupted", //
                                                   "Config entries for alias list and code list have different sizes, ignoring all."),
-                                            this);
+                                            widget());
         m_ui->verticalLayout->insertWidget(0, msg);
     }
 }
@@ -68,7 +68,7 @@ void CharacterRunnerConfig::save()
     KCModule::save();
 
     KSharedConfig::Ptr cfg = KSharedConfig::openConfig(QStringLiteral("krunnerrc"));
-    KConfigGroup grp = cfg->group("Runners").group("CharacterRunner");
+    KConfigGroup grp = cfg->group("Runners").group(KRUNNER_PLUGIN_NAME);
 
     grp.writeEntry(CONFIG_TRIGGERWORD, m_ui->edit_trigger->text().isEmpty() ? DEFAULT_TRIGGERWORD.toString() : m_ui->edit_trigger->text());
 
